summaryrefslogtreecommitdiffstats
path: root/source/core/slang-string-util.cpp
diff options
context:
space:
mode:
authorjsmall-nvidia <jsmall@nvidia.com>2021-02-02 17:45:56 -0500
committerGitHub <noreply@github.com>2021-02-02 14:45:56 -0800
commit17d2b2492d42e54ea4e0d907b4d84aa17f4a6f33 (patch)
treebdcc4b0aba860139a011ca052e505b9202c6152c /source/core/slang-string-util.cpp
parent5d755e584ff6c241f42204430e005b26314ed594 (diff)
Downstream compiler line number test (#1682)
* #include an absolute path didn't work - because paths were taken to always be relative. * WIP diagnostics for line number output. * Small param naming change * Use x macro for pass through compile human name lookup/getting. * WIP on parsing downstream compiler output. * Split out parsing into ParseDiagnosticUtil. Added test result of single line. * Dump out the std output on fail to parse diagnostics. * Change test type for syntax-error-intrinsic.slang be TEST not TEST_DIAGNOSTIC
Diffstat (limited to 'source/core/slang-string-util.cpp')
-rw-r--r--source/core/slang-string-util.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/source/core/slang-string-util.cpp b/source/core/slang-string-util.cpp
index 326bc3191..a859c6945 100644
--- a/source/core/slang-string-util.cpp
+++ b/source/core/slang-string-util.cpp
@@ -32,9 +32,9 @@ namespace Slang {
return areAllEqual(slicesA, slicesB, equalFn);
}
/* static */void StringUtil::split(const UnownedStringSlice& in, char splitChar, List<UnownedStringSlice>& slicesOut)
{
- slicesOut.clear();
+ outSlices.clear();
const char* start = in.begin();
const char* end = in.end();
@@ -49,7 +49,7 @@ namespace Slang {
}
// Add to output
- slicesOut.add(UnownedStringSlice(start, cur));
+ outSlices.add(UnownedStringSlice(start, cur));
// Skip the split character, if at end we are okay anyway
start = cur + 1;
@@ -32,9 +32,9 @@ namespace Slang {
return areAllEqual(slicesA, slicesB, equalFn);
}
-/* static */void StringUtil::split(const UnownedStringSlice& in, char splitChar, List<UnownedStringSlice>& slicesOut)
+/* static */void StringUtil::split(const UnownedStringSlice& in, char splitChar, List<UnownedStringSlice>& outSlices)
{